(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     24261,        853]
NotebookOptionsPosition[     20549,        721]
NotebookOutlinePosition[     20954,        738]
CellTagsIndexPosition[     20911,        735]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Impedance Routing", "Title"],

Cell[CellGroupData[{

Cell["Board Parameters", "Section"],

Cell["All units in mils", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Boardthickness", "=", "63"}], ";", "  ", 
   RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Copper", "=", "1.0"}], ";"}], "                    ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"oz", "/", "sq"}], " ", "inch"}], ";", " ", 
    RowBox[{
     RowBox[{"1", "oz"}], " ", "=", " ", 
     RowBox[{"1.4", "mil"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Corethickness", "=", "14"}], ";"}], "    ", 
  RowBox[{"(*", " ", "mil", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Prepregthickness", "=", "8.9"}], ";", "     ", 
   RowBox[{"(*", " ", "mil", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Er", "=", "4.2"}], ";"}], "                           ", 
  RowBox[{"(*", " ", 
   RowBox[{"dielectric", " ", "constant"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Layers", "=", "6"}], ";", "                     ", 
  RowBox[{"(*", "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"rule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"planethickness", "\[Rule]", "Prepregthickness"}], ",", 
     RowBox[{"planeplane", "\[Rule]", 
      RowBox[{
      "Corethickness", "+", "Prepregthickness", "+", "traceheight"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"corethickness", "\[Rule]", "Corethickness"}], ",", 
     RowBox[{"prepregthickness", "\[Rule]", "Prepregthickness"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"boardthickness", "\[Rule]", "Boardthickness"}], ",", 
     RowBox[{"er", "\[Rule]", "Er"}], ",", 
     RowBox[{"layers", "\[Rule]", "Layers"}], ",", 
     RowBox[{"copper", "\[Rule]", "Copper"}], ",", 
     RowBox[{"traceheight", "\[Rule]", 
      RowBox[{"copper", "*", "1.4"}]}]}], "}"}]}], ";", 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.429617748753625*^9, 3.429617801691125*^9}, {
  3.44077041784375*^9, 3.44077044534375*^9}}],

Cell["\<\
Check board thickness from build-up\
\>", "Text",
 CellChangeTimes->{{3.429617765347375*^9, 3.429617769113*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"layers", "*", "traceheight"}], "+", 
   RowBox[{
    FractionBox["layers", "2"], "*", "prepregthickness"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["layers", "2"], "-", "1"}], ")"}], "*", "corethickness"}]}],
   "//.", "rule"}]], "Input"],

Cell[BoxData["63.1`"], "Output",
 CellChangeTimes->{{3.429617770909875*^9, 3.4296178050505*^9}, 
   3.44077046028125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["87", 
    SqrtBox[
     RowBox[{"er", "+", "1.41"}]]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"5.98", "planethickness"}], 
     RowBox[{
      RowBox[{"0.8", "w"}], "+", "traceheight"}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speedm", ":=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox[
    RowBox[{
     RowBox[{"0.475", "er"}], "+", "0.67"}]], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Zm", "[", "8", "]"}], "//.", "rule"}]], "Input",
 CellChangeTimes->{3.440785772359375*^9}],

Cell[BoxData["70.5371298915964`"], "Output",
 CellChangeTimes->{3.429617809534875*^9, 3.440770469375*^9, 
  3.4407857729375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Zm", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input",
 CellChangeTimes->{{3.440785664921875*^9, 3.44078567634375*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.011494252873563218`"}], " ", 
        SqrtBox[
         RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
          RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}]], " ", 
      SuperscriptBox["planethickness", 
       "0.99999999999999999999999999991`15.906029430411715"]}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.429617809816125*^9, 3.440770469578125*^9, {3.440785665703125*^9, 
   3.44078567665625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "15.303974662517348`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.429617809816125*^9, 3.440770469578125*^9, {3.440785665703125*^9, 
   3.44078567665625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speedm", "//.", "rule"}]], "Input"],

Cell[BoxData["0.13835291490424043`"], "Output",
 CellChangeTimes->{3.429617809847375*^9, 3.440770469609375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Microstrip", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Zm", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.48", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.96"}], " ", 
        FractionBox["s", "planethickness"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZmDiff", "[", 
   RowBox[{"8", ",", "12"}], "]"}], "//.", "rule"}]], "Input",
 CellChangeTimes->{{3.440770525765625*^9, 3.440770540984375*^9}, {
  3.440785719078125*^9, 3.440785764140625*^9}, {3.44078612946875*^9, 
  3.440786190921875*^9}, {3.440786255328125*^9, 3.440786266109375*^9}, {
  3.440786855234375*^9, 3.44078687565625*^9}}],

Cell[BoxData["122.5156240423166`"], "Output",
 CellChangeTimes->{
  3.429617927597375*^9, {3.440770497046875*^9, 3.4407705415625*^9}, 
   3.440785681921875*^9, {3.440785719875*^9, 3.440785764625*^9}, {
   3.44078613196875*^9, 3.440786191421875*^9}, {3.4407862563125*^9, 
   3.44078626675*^9}, {3.440786858921875*^9, 3.4407868769375*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZmDiff", "[", 
      RowBox[{"w", ",", "8"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input",
 CellChangeTimes->{
  3.440770513984375*^9, {3.440785697296875*^9, 3.440785706296875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"7.4750000000000005`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"7.68`", "/", "planethickness"}]], " ", 
         SqrtBox[
          RowBox[{"1.41`", "\[InvisibleSpace]", "+", 
           RowBox[{"1.`", " ", "er"}]}]], " ", "Z0"}], 
        RowBox[{"2088.`", "\[InvisibleSpace]", "-", 
         RowBox[{"4350.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"7.68`", "/", "planethickness"}]]}]}]]], " ", 
      "planethickness"}], "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.429617927784875*^9, {3.440770497203125*^9, 3.440770514796875*^9}, {
   3.440785697875*^9, 3.440785707328125*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "10.319567036900724`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.429617927784875*^9, {3.440770497203125*^9, 3.440770514796875*^9}, {
   3.440785697875*^9, 3.440785707328125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stripline", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["60", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"4", " ", "planeplane"}], 
     RowBox[{"0.67", "\[Pi]", " ", "w", 
      RowBox[{"(", 
       RowBox[{"0.8", "+", 
        RowBox[{"traceheight", "/", "w"}]}], ")"}]}]], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Speed", ":=", 
  RowBox[{
   RowBox[{"1", "/", "12"}], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["65.91658354935613`"], "Output",
 CellChangeTimes->{{3.42961798026925*^9, 3.42961798908175*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "::", "\<\"ifun\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Inverse functions are being used by \\!\\(Solve\\), so \
some solutions may not be found; use Reduce for complete solution \
information. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/Solve/ifun\\\", ButtonNote -> \
\\\"Solve::ifun\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.42961798064425*^9, 3.42961798914425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{"1.25`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1.9003575294554667`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "0.016666666666666666`"}], " ", 
           SqrtBox["er"], " ", "Z0"}]], " ", 
         SuperscriptBox["planeplane", "1.`"]}], "-", 
        RowBox[{"1.`", " ", "traceheight"}]}], ")"}], 
      "1.`15.954589770191005"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.42961798914425*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "9.875457802127892`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.4296179806755*^9, 3.429617989159875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speed", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{{3.429617980722375*^9, 3.429617989191125*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential Stripline", "Section"],

Cell["\<\
w: width, s: separation (mil)
result in Ohms\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"w_", ",", "s_"}], "]"}], ":=", 
  RowBox[{"2", 
   RowBox[{"Z", "[", "w", "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"0.347", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2.9"}], " ", 
        FractionBox["s", "planeplane"]}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDiff", "[", 
   RowBox[{"5", ",", "8"}], "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["112.46080377813348`"], "Output",
 CellChangeTimes->{3.429617995128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDiff", "[", 
      RowBox[{"w", ",", "8"}], "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], "//",
   "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "100"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"2.375446911819333`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"25.`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"23.2`", "/", "planeplane"}]], " ", 
         SqrtBox["er"], " ", "Z0"}], 
        RowBox[{"1041.`", "\[InvisibleSpace]", "-", 
         RowBox[{"3000.`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"23.2`", "/", "planeplane"}]]}]}]]], " ", "planeplane"}], 
     "-", 
     RowBox[{"1.25`", " ", "traceheight"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429617995284875*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "6.912552465879912`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4296179953005*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dual Stripline", "Section"],

Cell[TextData[{
 "stacked on top between to planes\nlayer model: prepreg + core + prepreg\n\
conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", "prepregthickness"], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", "prepregthickness"], TraditionalForm]]],
 "< 0.25\nw: width"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "w_", "]"}], ":=", 
  RowBox[{
   FractionBox["80", 
    SqrtBox["er"]], 
   RowBox[{"Log", "[", 
    FractionBox[
     RowBox[{"1.9", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", "prepregthickness"}], "+", "traceheight"}], ")"}]}],
      
     RowBox[{
      RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["prepregthickness", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
        "prepregthickness", "+", "corethickness", "+", "traceheight"}], 
        ")"}]}]]}], ")"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "=", 
  RowBox[{
   FractionBox["1", "12"], "1.017", 
   SqrtBox["er"], "     ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"0.08474999999999999`", " ", 
  SqrtBox["er"]}]], "Output",
 CellChangeTimes->{3.429618155909875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ZDual", "[", "6", "]"}], "//.", "rule"}]], "Input"],

Cell[BoxData["44.031743372087774`"], "Output",
 CellChangeTimes->{3.429618155941125*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ZDual", "[", "w", "]"}], "\[Equal]", "Z0"}], ",", "w"}], "]"}], 
  "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1.`", " ", 
         SqrtBox["er"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1.`", " ", "corethickness"}], "+", 
           RowBox[{"1.`", " ", "prepregthickness"}], "+", 
           RowBox[{"1.`", " ", "traceheight"}]}], ")"}], " ", "Z0"}], 
        RowBox[{
         RowBox[{"80.`", " ", "corethickness"}], "+", 
         RowBox[{"60.`", " ", "prepregthickness"}], "+", 
         RowBox[{"80.`", " ", "traceheight"}]}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4.75`", " ", "prepregthickness"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.375`", "\[InvisibleSpace]", "-", 
          RowBox[{"1.25`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{
              SqrtBox["er"], " ", 
              RowBox[{"(", 
               RowBox[{
               "corethickness", "+", "prepregthickness", "+", "traceheight"}],
                ")"}], " ", "Z0"}], 
             RowBox[{
              RowBox[{"80.`", " ", "corethickness"}], "+", 
              RowBox[{"60.`", " ", "prepregthickness"}], "+", 
              RowBox[{"80.`", " ", "traceheight"}]}]]]}]}], ")"}], " ", 
        "traceheight"}]}], ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "4.856143391539851`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618156128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpeedDual", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618156159875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Asymmetric Stripline", "Section"],

Cell[TextData[{
 "hhh: smaller layer thickness\nhhh1: greater layer thickness\n",
 "conditions: 0.1 < ",
 Cell[BoxData[
  FormBox[
   FractionBox["w", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 " < 2.0 and ",
 Cell[BoxData[
  FormBox[
   FractionBox["traceheight", 
    RowBox[{"smaller", " ", "layer", " ", "thickness"}]], TraditionalForm]]],
 "< 0.25"
}], "Text"],

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{"ReplaceAll", "::", "reps"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Za", "[", "w_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["80", 
     SqrtBox["er"]], 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"1.9", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "hhh"}], "+", "traceheight"}], ")"}]}], 
      RowBox[{
       RowBox[{"0.8", " ", "w"}], "+", "traceheight"}]], "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["hhh", 
       RowBox[{"4", " ", "hhh1"}]]}], ")"}]}], "/.", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"prepregthickness", ">", "corethickness"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh1", "\[Rule]", "prepregthickness"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hhh1", "\[Rule]", "corethickness"}], ",", 
       RowBox[{"hhh", "\[Rule]", "prepregthickness"}]}], "}"}]}], 
    "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Speeda", ":=", 
  RowBox[{
   FractionBox["1", "12"], " ", "1.017", 
   SqrtBox["Er"], "      ", 
   RowBox[{"(*", " ", 
    RowBox[{"in", " ", 
     RowBox[{"ns", "/", "inch"}]}], " ", "*)"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Za", "[", "5", "]"}], "//.", "rule"}], "//", "N"}]], "Input"],

Cell[BoxData["48.56958436407749`"], "Output",
 CellChangeTimes->{3.42961814808175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Za", "[", "w", "]"}], "//.", "rule"}], ")"}], "\[Equal]", 
     "Z0"}], ",", "w"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"Z0", "\[Rule]", "50"}]}], "//.", "rule"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1.75`"}], "+", 
     RowBox[{"25.174999999999986`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.027101507063621105`"}], " ", "Z0"}]]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"w", "\[Rule]", "4.743333826029893`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.429618148128625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Speeda", "//.", "rule", "                       ", 
  RowBox[{"(*", " ", 
   RowBox[{"ns", "/", "inch"}], " ", "*)"}]}]], "Input"],

Cell[BoxData["0.1736858154830152`"], "Output",
 CellChangeTimes->{3.429618148159875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{925, 1028},
WindowMargins->{{385, Automatic}, {Automatic, -4}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 34, 0, 83, "Title"],
Cell[CellGroupData[{
Cell[649, 27, 35, 0, 71, "Section"],
Cell[687, 29, 33, 0, 29, "Text"],
Cell[723, 31, 1959, 46, 212, "Input"],
Cell[2685, 79, 122, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[2832, 86, 313, 10, 45, "Input"],
Cell[3148, 98, 121, 2, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3318, 106, 29, 0, 71, "Section"],
Cell[3350, 108, 316, 11, 51, "Input"],
Cell[3669, 121, 278, 9, 45, "Input"],
Cell[CellGroupData[{
Cell[3972, 134, 125, 3, 31, "Input"],
Cell[4100, 139, 128, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4265, 146, 359, 10, 52, "Input"],
Cell[4627, 158, 668, 17, 42, "Output"],
Cell[5298, 177, 237, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5572, 188, 59, 1, 31, "Input"],
Cell[5634, 191, 111, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5794, 198, 42, 0, 71, "Section"],
Cell[5839, 200, 369, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[6233, 216, 369, 7, 31, "Input"],
Cell[6605, 225, 337, 5, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6979, 235, 417, 12, 52, "Input"],
Cell[7399, 249, 889, 22, 55, "Output"],
Cell[8291, 273, 259, 6, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8599, 285, 28, 0, 71, "Section"],
Cell[8630, 287, 363, 12, 51, "Input"],
Cell[8996, 301, 232, 7, 34, "Input"],
Cell[CellGroupData[{
Cell[9253, 312, 107, 3, 31, "Input"],
Cell[9363, 317, 109, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9509, 323, 293, 9, 52, "Input"],
Cell[9805, 334, 512, 10, 21, "Message"],
Cell[10320, 346, 600, 16, 47, "Output"],
Cell[10923, 364, 184, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11144, 373, 153, 3, 31, "Input"],
Cell[11300, 378, 112, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11461, 385, 41, 0, 71, "Section"],
Cell[11505, 387, 68, 3, 47, "Text"],
Cell[11576, 392, 363, 12, 47, "Input"],
Cell[CellGroupData[{
Cell[11964, 408, 110, 3, 31, "Input"],
Cell[12077, 413, 88, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12202, 419, 325, 10, 52, "Input"],
Cell[12530, 431, 689, 18, 55, "Output"],
Cell[13222, 451, 160, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13431, 461, 33, 0, 71, "Section"],
Cell[13467, 463, 345, 11, 94, "Text"],
Cell[13815, 476, 638, 22, 51, "Input"],
Cell[CellGroupData[{
Cell[14478, 502, 227, 7, 45, "Input"],
Cell[14708, 511, 124, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14869, 519, 86, 2, 31, "Input"],
Cell[14958, 523, 88, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15083, 529, 297, 9, 52, "Input"],
Cell[15383, 540, 1476, 39, 115, "Output"],
Cell[16862, 581, 162, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17061, 590, 157, 3, 31, "Input"],
Cell[17221, 595, 88, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17358, 602, 39, 0, 71, "Section"],
Cell[17400, 604, 402, 13, 76, "Text"],
Cell[17805, 619, 1047, 32, 115, "Input"],
Cell[18855, 653, 231, 7, 45, "Input"],
Cell[CellGroupData[{
Cell[19111, 664, 108, 3, 31, "Input"],
Cell[19222, 669, 86, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19345, 675, 357, 11, 52, "Input"],
Cell[19705, 688, 357, 11, 33, "Output"],
Cell[20065, 701, 162, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20264, 710, 154, 3, 31, "Input"],
Cell[20421, 715, 88, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
